#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 opentelemetry
version:              0.7.0
visibility:           public
id:                   opentelemetry-0.7.0-GZraeyjLM6c8wtPHcMbr0h
key:                  opentelemetry-0.7.0-GZraeyjLM6c8wtPHcMbr0h
license:              Apache-2.0
maintainer:           ethercrow@gmail.com
author:               Dmitry Ivanov
description:          The OpenTelemetry Haskell Client https://opentelemetry.io
category:             OpenTelemetry
abi:                  7b6048c8fc16fcf22d6899d20a47e810
exposed:              True
exposed-modules:
    OpenTelemetry.Eventlog OpenTelemetry.Eventlog_Internal
    OpenTelemetry.Metrics_Internal OpenTelemetry.Propagation
    OpenTelemetry.SpanContext

import-dirs:          /usr/lib/ghc-8.10.5/site-local/opentelemetry-0.7.0
library-dirs:         /usr/lib/ghc-8.10.5/site-local/opentelemetry-0.7.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/opentelemetry-0.7.0
hs-libraries:         HSopentelemetry-0.7.0-GZraeyjLM6c8wtPHcMbr0h
depends:
    base-4.14.2.0 bytestring-0.10.12.0 exceptions-0.10.4
    ghc-trace-events-0.1.2.2-HKKNHycmX1BLp8J2VitI9Z
    hashable-1.3.2.0-GpzwVyCMdDv8NwdC61S1EE

haddock-interfaces:
    /usr/share/doc/haskell-opentelemetry/html/opentelemetry.haddock

haddock-html:         /usr/share/doc/haskell-opentelemetry/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

